@@ -1,6 +1,5 @@
 #!/usr/bin/python3
 import os
-import sys
 from argparse import ArgumentParser
 from .app import App
 from .libs.setuptools import get_file_content
@@ -8,11 +7,12 @@ from .libs.setuptools import get_file_content
 
 def _handle_args():
     version = get_file_content(os.path.join(os.path.dirname(__file__), "VERSION"))
-    parser = ArgumentParser(description=f"Scan Image WEB UI v{version}")
+    parser = ArgumentParser(description="Scan Image WEB UI v{version}".format(version=version))
     parser.add_argument("-p", "--port", dest="port", default=7800, type=int, help="APP server port")
     parser.add_argument("-d", "--scan-directory", dest="scan_diretory", type=str, help="Directory where scanned images will be stored.")
 
     args = parser.parse_args()
+    args.__setattr__("version", version)
 
     if not args.scan_diretory:
         home = os.path.expanduser("~")
@@ -25,9 +25,9 @@ def _handle_args():
 
 def main():
     app_args = _handle_args()
-    print(f"Images will scanned into folder: '{app_args.scan_diretory}'")
+    print("Images will scanned into folder: '{}'".format(app_args.scan_diretory))
     app = App()
-    app.init(scan_folder_path=app_args.scan_diretory, port=app_args.port)
+    app.init(port=app_args.port, scan_folder_path=app_args.scan_diretory, version=app_args.version)
     app.run()
 
 
